@@ -1,4 +1,4 @@
-if [ ! -f /etc/discusrc ]
+if [ ! -e /etc/discusrc ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/discusrc /etc/discusrc
